@@ -2,24 +2,23 @@
 #'
 #' Plot a selected motif and range of columns of the dataset
 #' @param dataset Dataset containing numeric values
-#' @param rankList List of ranked motifs
+#' @param rmotifs List of ranked motifs
 #' @param position Select by an integer a motif with his position
 #' @param space Select a range of columns to plot the corresponding spatial series
 #' @return Plot the spatial series
 #' @import ggplot2
 #' @import reshape2
 #' @examples
-#'#Launch all the workflow
-#'candidates <- STSIdentifyCandidateSTMotifs(STMotif::example_dataset, 10, 10, 7, 3)
-#'stmotifs <- STSIdentifySTMotifs(candidates, 1, 1)
-#'sttightmotifs <- STSIdentifyTightSTMotifs(stmotifs, candidates$rectangles)
-#'rankResult <- STSRankTightSTMotifs(sttightmotifs)
-#'
-#'#Plot the result
-#'displayPlotSeries(dataset = STMotif::example_dataset, rankResult, 1, 2:11)
+#' #Launch all the workflow
+#' #Plot the result
+#' D  <- STMotif::example_dataset
+#' DS <- NormSAX(STMotif::example_dataset,7)
+#' stmotifs <- SearchSTMotifs(D,DS,3,7,10,10,3,7)
+#' rstmotifs <- RankSTMotifs(stmotifs)
+#' displayPlotSeries(dataset = D, rmotifs = rstmotifs ,position = 1 ,space = c(1,2,5:7))
 #' @export
-displayPlotSeries <- function(dataset, rankList, position, space){
-  size_motif <- length(rankList[[1]]$saxcod)
+displayPlotSeries <- function(dataset, rmotifs, position, space){
+  size_motif <- nchar(rmotifs[[1]]$isaxcod)
   namesCol <- paste("X",colnames(dataset),sep = "")
   data <- as.data.frame(dataset[,space])
   colnames(data) <- paste("X",colnames(dataset)[space], sep = "")
@@ -27,15 +26,17 @@ displayPlotSeries <- function(dataset, rankList, position, space){
   data <- reshape2::melt(data,id.vars = 1)
   data <- data.frame(data, color = "black")
   levels(data$color) <- c("black", "red")
-  for(i in 1:length(rankList[[position]]$vecst$s)){
-    if(rankList[[position]]$vecst$s[i]%in%space){
-      data[data$variable==namesCol[rankList[[position]]$vecst$s[i]],][(rankList[[position]]$vecst$t[i]):(rankList[[position]]$vecst$t[i]+(size_motif-1)),4] <- "red"
+  for(i in 1:length(rmotifs[[position]]$vecst$s)){
+    if(rmotifs[[position]]$vecst$s[i]%in%space){
+      data[data$variable==namesCol[rmotifs[[position]]$vecst$s[i]],][(rmotifs[[position]]$vecst$t[i]):(rmotifs[[position]]$vecst$t[i]+(size_motif-1)),4] <- "red"
     }
   }
   plot.series(data[1:nrow(data),])
 }
 
 
+
+
 #' Plot the intensity of values
 #'
 #' Display the intensity of values and higthlight one motif
@@ -49,14 +50,13 @@ displayPlotSeries <- function(dataset, rankList, position, space){
 #' @import scales
 #' @importFrom grDevices grey.colors
 #' @examples
-#'#Launch all the workflow
-#'candidates <- STSIdentifyCandidateSTMotifs(STMotif::example_dataset, 10, 10, 7, 3)
-#'stmotifs <- STSIdentifySTMotifs(candidates, 1, 1)
-#'sttightmotifs <- STSIdentifyTightSTMotifs(stmotifs, candidates$rectangles)
-#'rankResult <- STSRankTightSTMotifs(sttightmotifs)
-#'
-#'#Plot the result
-#'intensityDataset(dataset = STMotif::example_dataset, rankResult, 1, 7)
+#' #Launch all the workflow
+#' #Plot the result
+#' D  <- STMotif::example_dataset
+#' DS <- NormSAX(STMotif::example_dataset,7)
+#' stmotifs <- SearchSTMotifs(D,DS,3,7,10,10,3,7)
+#' rstmotifs <- RankSTMotifs(stmotifs)
+#' intensityDataset(dataset = STMotif::example_dataset, rankList = rstmotifs, 1, 7)
 #' @export
 intensityDataset <- function(dataset,rankList,position,alpha){
   colorEncode <- 1:alpha
@@ -99,14 +99,13 @@ intensityDataset <- function(dataset,rankList,position,alpha){
 #' @import scales
 #' @importFrom grDevices grey.colors
 #' @examples
-#'#Launch all the workflow
-#'candidates <- STSIdentifyCandidateSTMotifs(STMotif::example_dataset, 10, 10, 7, 3)
-#'stmotifs <- STSIdentifySTMotifs(candidates, 1, 1)
-#'sttightmotifs <- STSIdentifyTightSTMotifs(stmotifs, candidates$rectangles)
-#'rankResult <- STSRankTightSTMotifs(sttightmotifs)
-#'
-#'#Plot the result
-#'top5motifs(dataset = STMotif::example_dataset, rankList = rankResult, alpha = 7)
+#' #Launch all the workflow
+#' D  <- STMotif::example_dataset
+#' DS <- NormSAX(STMotif::example_dataset,7)
+#' stmotifs <- SearchSTMotifs(D,DS,3,7,10,10,3,7)
+#' rstmotifs <- RankSTMotifs(stmotifs)
+#' #Plot the result
+#' top5motifs(dataset = STMotif::example_dataset, rankList = rstmotifs, alpha = 7)
 #' @export
 top5motifs <- function(dataset,rankList,alpha){
   colorEncode <- 1:alpha
@@ -131,19 +130,15 @@ top5motifs <- function(dataset,rankList,alpha){
   ggplot(data=datasetColor, aes(x=datasetColor$Var1, y=datasetColor$Var2, fill=datasetColor$value)) +
     geom_raster() +
     scale_fill_gradientn(colours = c("white","dimgrey"), values = scales::rescale(1:alpha), limits=c(1,alpha))+
-    geom_point(aes(size=ifelse(datasetColor$motif == 1, "dot1", "no_dot1"),colour=ifelse(datasetColor$motif == 1, "dot1", "no_dot1")), na.rm=T) +
-    geom_point(aes(size=ifelse(datasetColor$motif == 2, "dot2", "no_dot2"),colour=ifelse(datasetColor$motif == 2, "dot2", "no_dot2")), na.rm=T) +
-    geom_point(aes(size=ifelse(datasetColor$motif == 3, "dot3", "no_dot3"),colour=ifelse(datasetColor$motif == 3, "dot3", "no_dot3")), na.rm=T) +
-    geom_point(aes(size=ifelse(datasetColor$motif == 4, "dot4", "no_dot4"),colour=ifelse(datasetColor$motif == 4, "dot4", "no_dot4")), na.rm=T) +
-    geom_point(aes(size=ifelse(datasetColor$motif == 5, "dot5", "no_dot5"),colour=ifelse(datasetColor$motif == 5, "dot5", "no_dot5")), na.rm=T) +
-    scale_colour_manual(name="", values = c("dot1"="yellow", "dot2"="red", "dot3"="orange", "dot4"="blue", "dot5"="green", "no_dot1"=NA,"no_dot2"=NA,"no_dot3"=NA,"no_dot4"=NA,"no_dot5"=NA),labels = c('Motif1','Motif2','Motif3','Motif4','Motif5','','','','',''))+
     scale_size_manual(values=c("dot1"=1, "dot2"=1, "dot3"=1, "dot4"=1, "dot5"=1, "no_dot1"=NA,"no_dot2"=NA,"no_dot3"=NA,"no_dot4"=NA,"no_dot5"=NA), guide="none") +
     theme_bw() +
-    ggtitle("Intensity of values in the dataset") + xlab("Space") + ylab("Time") +
-    guides(fill=guide_legend(title="SAX Encode")) + scale_y_reverse()
+    ggtitle("") + xlab("") + ylab("") +
+    guides(fill=guide_legend(title="")) + scale_y_reverse()
 }
 
 
+
+
 #' Interactive visualization
 #'
 #' Launch a process to have an interactive visualization
@@ -154,14 +149,13 @@ top5motifs <- function(dataset,rankList,alpha){
 #' @import utils
 #' @examples
 #'\dontrun{
-#'#Launch all the workflow
-#'candidates <- STSIdentifyCandidateSTMotifs(STMotif::example_dataset, 10, 10, 7, 3)
-#'stmotifs <- STSIdentifySTMotifs(candidates, 1, 1)
-#'sttightmotifs <- STSIdentifyTightSTMotifs(stmotifs, candidates$rectangles)
-#'rankResult <- STSRankTightSTMotifs(sttightmotifs)
-#'
-#'#Launch the process
-#'runVisualization(dataset = STMotif::example_dataset, rankResult, 7)
+#' #Launch all the workflow
+#' D  <- STMotif::example_dataset
+#' DS <- NormSAX(STMotif::example_dataset,7)
+#' stmotifs <- SearchSTMotifs(D,DS,3,7,10,10,3,7)
+#' rstmotifs <- RankSTMotifs(stmotifs)
+#' #Launch the process
+#' runVisualization(dataset = STMotif::example_dataset, rstmotifs, 7)
 #'}
 #' @export
 runVisualization <- function(dataset, rankList, alpha){
